==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-flatButton.dart <==
/*
Description:

Dynamically creates a FlatButton material widget which responds to a press and long press.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-flatButton.dart';

Usage:

The 'child' parameter accepts a widget to be displayed on the button and can be specified to be a Text, Icon, Image,etc.
The parameters such as shape,color,width,height,focusColor,hoverColor,highlightColor,splashColor,etc can be passed using the class 'FlatButtonParameters'.
onPress, & onLongPress callback functions can be passed which returns a 'true' value and can be used to define further actions to be performed on press & on long press respectively.
 A flatButton with default parameters is created when null is passed as FlatButtonParameters.




- Defining the callback and FlatButton objects

onButtonPress(bool b){
      print(b);
    }

    onButtonLongPress(bool b){
      print(b);
    }
    FlatButtonParameters buttonObject = FlatButtonParameters(child:Text('Submit'),color:Colors.pinkAccent,textColor:Colors.white,hoverColor: Colors.grey,width: 150,focusColor: Colors.grey,height: 50,highlightColor: Colors.grey,splashColor: Colors.white);


- Object call for the widget

customFlatButton(buttonObject, onButtonPress, onButtonLongPress),

Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'consts.dart' as con;
import 'widget-classesUsed.dart';
import 'theme.dart';

Widget customFlatButton(
  FlatButtonParameters param,
  void Function(bool) onPress,
  void Function(bool) onLongPress,
) {
  if (param == null && onPress == null && onLongPress == null) {
    return ButtonTheme(
      minWidth: con.heightHundred,
      height: con.heightTwenty,
      child: FlatButton(
        child: Text(con.buttonLabel),
        color: mediumGreyThemeData().buttonColor,
        colorBrightness: mediumGreyThemeData().brightness,
        disabledColor: mediumGreyThemeData().disabledColor,
        disabledTextColor: mediumGreyThemeData().disabledColor,
        focusColor: mediumGreyThemeData().focusColor,
        highlightColor: mediumGreyThemeData().highlightColor,
        hoverColor: mediumGreyThemeData().hoverColor,
        onPressed: () {},
        onLongPress: () {},
        shape: con.outlineButtonShape,
      ),
    );
  } else {
    return ButtonTheme(
      minWidth: param.width != null ? param.width : con.heightHundred,
      height: param.height != null ? param.height : con.heightTwenty,
      child: FlatButton(
        autofocus: param.autofocus != null ? param.autofocus : false,
        child: param.child != null ? param.child : Text(con.buttonLabel),
        color: (param.color != null)
            ? param.color
            : mediumGreyThemeData().buttonColor,
        colorBrightness: (param.colorBrightness != null)
            ? param.colorBrightness
            : mediumGreyThemeData().brightness,
        disabledColor: (param.disabledColor != null)
            ? param.disabledColor
            : mediumGreyThemeData().disabledColor,
        disabledTextColor: (param.disabledTextColor != null)
            ? param.disabledTextColor
            : mediumGreyThemeData().disabledColor,
        focusColor: (param.focusColor != null)
            ? param.focusColor
            : mediumGreyThemeData().focusColor,
        highlightColor: (param.highlightColor != null)
            ? param.highlightColor
            : mediumGreyThemeData().highlightColor,
        hoverColor: (param.hoverColor != null)
            ? param.hoverColor
            : mediumGreyThemeData().hoverColor,
        splashColor: (param.splashColor != null)
            ? param.splashColor
            : mediumGreyThemeData().splashColor,
        shape: (param.shape != null) ? param.shape : con.outlineButtonShape,
        textColor: (param.textColor != null)
            ? param.textColor
            : mediumGreyThemeData().textSelectionColor,
        focusNode: param.focusNode,
        textTheme: param.textTheme,
        onPressed: () {
          return (onPress != null) ? onPress(true) : null;
        },
        onLongPress: () {
          return (onLongPress != null) ? onLongPress(true) : null;
        },
        key: param.key,
      ),
    );
  }
}

==> flutter_catalogue_widgets-0.0.15.tar.gz: lib/custom-flatButton.dart <==
/*
Description:

Dynamically creates a FlatButton material widget which responds to a press and long press.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-flatButton.dart';

Usage:

The 'child' parameter accepts a widget to be displayed on the button and can be specified to be a Text, Icon, Image,etc.
The parameters such as shape,color,width,height,focusColor,hoverColor,highlightColor,splashColor,etc can be passed using the class 'FlatButtonParameters'.
onPress, & onLongPress callback functions can be passed which returns a 'true' value and can be used to define further actions to be performed on press & on long press respectively.
 A flatButton with default parameters is created when null is passed as FlatButtonParameters.




- Defining the callback and FlatButton objects

onButtonPress(bool b){
      print(b);
    }

    onButtonLongPress(bool b){
      print(b);
    }
    FlatButtonParameters buttonObject = FlatButtonParameters(child:Text('Submit'),color:Colors.pinkAccent,textColor:Colors.white,hoverColor: Colors.grey,width: 150,focusColor: Colors.grey,height: 50,highlightColor: Colors.grey,splashColor: Colors.white);


- Object call for the widget

customFlatButton(buttonObject, onButtonPress, onButtonLongPress),

Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as con;
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';
import 'theme.dart';

Widget customFlatButton(
  FlatButtonParameters param,
  void Function(bool) onPress,
  void Function(bool) onLongPress,
) {
  if (param == null && onPress == null && onLongPress == null) {
    return ButtonTheme(
      minWidth: con.heightHundred,
      height: con.heightTwenty,
      child: FlatButton(
        child: Text(con.buttonLabel),
        color: mediumGreyThemeData().buttonColor,
        colorBrightness: mediumGreyThemeData().brightness,
        disabledColor: mediumGreyThemeData().disabledColor,
        disabledTextColor: mediumGreyThemeData().disabledColor,
        focusColor: mediumGreyThemeData().focusColor,
        highlightColor: mediumGreyThemeData().highlightColor,
        hoverColor: mediumGreyThemeData().hoverColor,
        onPressed: () {},
        onLongPress: () {},
        shape: con.outlineButtonShape,
      ),
    );
  } else {
    return ButtonTheme(
      minWidth: param.width != null ? param.width : con.heightHundred,
      height: param.height != null ? param.height : con.heightTwenty,
      child: FlatButton(
        autofocus: param.autofocus != null ? param.autofocus : false,
        child: param.child != null ? param.child : Text(con.buttonLabel),
        color: (param.color != null)
            ? param.color
            : mediumGreyThemeData().buttonColor,
        colorBrightness: (param.colorBrightness != null)
            ? param.colorBrightness
            : mediumGreyThemeData().brightness,
        disabledColor: (param.disabledColor != null)
            ? param.disabledColor
            : mediumGreyThemeData().disabledColor,
        disabledTextColor: (param.disabledTextColor != null)
            ? param.disabledTextColor
            : mediumGreyThemeData().disabledColor,
        focusColor: (param.focusColor != null)
            ? param.focusColor
            : mediumGreyThemeData().focusColor,
        highlightColor: (param.highlightColor != null)
            ? param.highlightColor
            : mediumGreyThemeData().highlightColor,
        hoverColor: (param.hoverColor != null)
            ? param.hoverColor
            : mediumGreyThemeData().hoverColor,
        splashColor: (param.splashColor != null)
            ? param.splashColor
            : mediumGreyThemeData().splashColor,
        shape: (param.shape != null) ? param.shape : con.outlineButtonShape,
        textColor: (param.textColor != null)
            ? param.textColor
            : mediumGreyThemeData().textSelectionColor,
        focusNode: param.focusNode,
        textTheme: param.textTheme,
        onPressed: () {
          return (onPress != null) ? onPress(true) : null;
        },
        onLongPress: () {
          return (onLongPress != null) ? onLongPress(true) : null;
        },
        key: param.key,
      ),
    );
  }
}
